@@ -7,6 +7,7 @@ authorization is required to interact with private documents.
 
 Further documentation:
 
+    http://datadesk.github.io/python-documentcloud/
     https://www.documentcloud.org/help/api
 
 """
@@ -501,11 +502,11 @@ class Document(BaseAPIObject):
         Returns nothing.
         """
         params = dict(
-            title=self.title,
-            source=self.source,
-            description=self.description,
-            related_article=self.resources.related_article,
-            published_url=self.resources.published_url,
+            title=self.title or '',
+            source=self.source or '',
+            description=self.description or '',
+            related_article=self.resources.related_article or '',
+            published_url=self.resources.published_url or '',
             access=self.access,
             data=self.data,
         )
@@ -842,7 +843,7 @@ class Document(BaseAPIObject):
 
 class DocumentSet(list):
     """
-    A custom class for project lists associated with projects.
+    A custom class for document lists associated with projects.
     
     Allows some tweaks, like preventing duplicate documents
     from getting into the list and ensuring that only Document
@@ -932,8 +933,8 @@ class Project(BaseAPIObject):
         Returns nothing.
         """
         params = dict(
-            title=self.title,
-            description=self.description,
+            title=self.title or '',
+            description=self.description or '',
             document_ids=[str(i.id) for i in self.document_list]
         )
         self._connection.put('projects/%s.json' % self.id, params)
